@@ -260,7 +260,7 @@ def get_document_by_id(config: Config, index_name:str, document_id: str):
         f'{index_name}/_doc/{document_id}'
     )
     if "_source" in res:
-        return _clean_doc(res["_source"])
+        return _clean_doc(res["_source"], doc_id=document_id)
     else:
         return res
 
